summaryrefslogtreecommitdiff
path: root/src/library/scala/reflect/DummyMirror.scala
diff options
context:
space:
mode:
Diffstat (limited to 'src/library/scala/reflect/DummyMirror.scala')
-rw-r--r--src/library/scala/reflect/DummyMirror.scala6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/library/scala/reflect/DummyMirror.scala b/src/library/scala/reflect/DummyMirror.scala
index 1fbf36be9d..9607621928 100644
--- a/src/library/scala/reflect/DummyMirror.scala
+++ b/src/library/scala/reflect/DummyMirror.scala
@@ -161,8 +161,8 @@ class DummyMirror(cl: ClassLoader) extends api.Mirror {
def wrappingPos(trees: List[Tree]): Position = notSupported()
def wrappingPos(default: Position,trees: List[Tree]): Position = notSupported()
- // Members declared in scala.reflect.api.Reporters
- def mkConsoleReporter(minSeverity: Int): Reporter = notSupported()
+ // Members declared in scala.reflect.api.FrontEnds
+ def mkConsoleFrontEnd(minSeverity: Int): FrontEnd = notSupported()
// Members declared in scala.reflect.api.Scopes
type Scope = DummyScope.type
@@ -471,7 +471,7 @@ class DummyMirror(cl: ClassLoader) extends api.Mirror {
}
// Members declared in scala.reflect.api.ToolBoxes
- def mkToolBox(reporter: Reporter,options: String): AbsToolBox = notSupported()
+ def mkToolBox(frontEnd: FrontEnd, options: String): AbsToolBox = notSupported()
// Members declared in scala.reflect.api.TreeBuildUtil
// type TreeGen = DummyTreeGen.type // [Eugene] cannot compile if uncomment this